@@ -1,12 +1,12 @@
 package Net::CLI::Interact;
 {
-  $Net::CLI::Interact::VERSION = '2.200007_001';
+  $Net::CLI::Interact::VERSION = '2.122630';
 }
 
 use Moo;
 use Sub::Quote;
 use Class::Load ();
-use MooX::Types::MooseLike::Base qw(InstanceOf Maybe Str HashRef);
+use MooX::Types::MooseLike::Base qw(InstanceOf Str HashRef);
 
 with 'Net::CLI::Interact::Role::Engine';
 
@@ -25,13 +25,9 @@ sub BUILDARGS {
     return { my_args => $params };
 }
 
-sub default_log_categories {
-    return (qw/dialogue dump engine object phrasebook prompt transport/);
-}
-
 has 'log_at' => (
     is => 'rw',
-    isa => Maybe[Str],
+    isa => Str,
     default => quote_sub(q[ $ENV{'NCI_LOG_AT'} ]),
     trigger => \&set_global_log_at,
 );
@@ -40,7 +36,7 @@ sub set_global_log_at {
     my ($self, $level) = @_;
     return unless defined $level and length $level;
     $self->logger->log_flags({
-        map {$_ => $level} default_log_categories()
+        map {$_ => $level} qw/dump engine phrasebook prompt transport/
     });
 }
 
@@ -118,6 +114,10 @@ __END__
 
 Net::CLI::Interact - Toolkit for CLI Automation
 
+=head1 VERSION
+
+version 2.122630
+
 =head1 PURPOSE
 
 This module exists to support developers of applications and libraries which
@@ -215,14 +215,6 @@ library will be enabled at that level. Use C<debug> to learn about how the
 library is working internally. See L<Net::CLI::Interact::Logger> for a list of
 the valid level names.
 
-=item C<< timeout => $seconds >>
-
-Configures a default timeout value, in seconds, for interaction with the
-remote device. The default is 10 seconds. You can also set timeout on a
-per-command or per-macro call (see below).
-
-Note that this does not (currently) apply to the initial connection.
-
 =back
 
 =head2 cmd( $command )
@@ -337,7 +329,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Oliver Gorwits.
+This software is copyright (c) 2012 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
