@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Logger;
 {
-  $Net::CLI::Interact::Logger::VERSION = '2.123370_002';
+  $Net::CLI::Interact::Logger::VERSION = '2.122630';
 }
 
 use Moo;
@@ -13,7 +13,7 @@ use Log::Dispatch::Config; # loads Log::Dispatch
 use Log::Dispatch::Configurator::Any;
 
 has log_config => (
-    is => 'rw',
+    is => 'ro',
     isa => HashRef,
     builder => 1,
 );
@@ -124,7 +124,7 @@ Net::CLI::Interact::Logger - Per-instance multi-target logging, with categories
 
 =head1 VERSION
 
-version 2.123370_002
+version 2.122630
 
 =head1 SYNOPSIS
 
