@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Role::Engine;
 {
-  $Net::CLI::Interact::Role::Engine::VERSION = '2.143070';
+  $Net::CLI::Interact::Role::Engine::VERSION = '2.122630';
 }
 
 {
@@ -45,37 +45,23 @@ with 'Net::CLI::Interact::Role::Prompt';
 
 use Net::CLI::Interact::Action;
 use Net::CLI::Interact::ActionSet;
-use Class::Load ();
-
-# try to load Data::Printer for last_actionset debug output
-if (Class::Load::try_load_class('Data::Printer', {-version => '0.27'})) {
-    Data::Printer->import({class => { expand => 'all' }});
-}
 
 has 'last_actionset' => (
     is => 'rw',
     isa => InstanceOf['Net::CLI::Interact::ActionSet'],
-    trigger => 1,
+    trigger => sub {
+        (shift)->logger->log('prompt', 'notice',
+            sprintf ('prompt matched was "%s"', (shift)->item_at(-1)->response));
+    },
 );
 
-sub _trigger_last_actionset {
-    my ($self, $new) = @_;
-    $self->logger->log('prompt', 'notice',
-        sprintf ('output matching prompt was "%s"', $new->item_at(-1)->response));
-    if (Class::Load::is_class_loaded('Data::Printer', {-version => '0.27'})) {
-        Data::Printer::p($new, output => \my $debug);
-        $self->logger->log('object', 'debug', $debug);
-    }
-}
-
 sub last_response {
     my $self = shift;
     my $irs_re = $self->transport->irs_re;
     (my $resp = $self->last_actionset->item_at(-2)->response) =~ s/$irs_re/\n/g;
-    $resp =~ s/\n+$//;
     return (wantarray
         ? (map {$_ .= "\n"} split m/\n/, $resp)
-        : ($resp ."\n"));
+        : $resp);
 }
 
 has 'default_continuation' => (
@@ -169,13 +155,11 @@ sub _execute_actions {
     $self->transport->timeout($timeout_bak);
     $self->last_actionset($set);
 
-    $self->logger->log('prompt', 'debug',
+    $self->logger->log('prompt', 'info',
         sprintf 'setting new prompt to %s',
             $self->last_actionset->last->prompt_hit || '<none>');
     $self->_prompt( $self->last_actionset->last->prompt_hit );
 
-    $self->logger->log('dialogue', 'info',
-        "trimmed command response:\n". $self->last_response);
     return $self->last_response; # context sensitive
 }
 
@@ -193,7 +177,7 @@ Net::CLI::Interact::Role::Engine - Statement execution engine
 
 =head1 VERSION
 
-version 2.143070
+version 2.122630
 
 =head1 DESCRIPTION
 
@@ -313,7 +297,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Oliver Gorwits.
+This software is copyright (c) 2012 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
