@@ -1,23 +1,28 @@
 package Net::CLI::Interact::Transport::Base::Unix;
 {
-  $Net::CLI::Interact::Transport::Base::Unix::VERSION = '1.122530';
+  $Net::CLI::Interact::Transport::Base::Unix::VERSION = '2.122630';
 }
 
-use Moose;
-use Moose::Util::TypeConstraints;
+use Moo;
+use Sub::Quote;
+use MooX::Types::MooseLike::Base qw(Str InstanceOf);
 
 extends 'Net::CLI::Interact::Transport::Base';
 
 {
     package # hide from pause
         Net::CLI::Interact::Transport::Platform::Options;
-    use Moose;
+
+    use Moo;
+    use Sub::Quote;
+    use MooX::Types::MooseLike::Base qw(Int);
+
     extends 'Net::CLI::Interact::Transport::Base::Options';
 
     has 'reap' => (
         is => 'rw',
-        isa => 'Int',
-        default => 0,
+        isa => Int,
+        default => quote_sub('0'),
     );
 }
 
@@ -25,9 +30,8 @@ sub put { (shift)->wrapper->put( join '', @_ ) }
 
 has '_buffer' => (
     is => 'rw',
-    isa => 'Str',
-    default => '',
-    required => 0,
+    isa => Str,
+    default => quote_sub(q{''}),
 );
 
 sub buffer {
@@ -43,20 +47,18 @@ sub pump {
 }
 
 has '+timeout' => (
-    trigger => sub {
-        (shift)->wrapper->timeout(shift) if scalar @_ > 1;
-    },
+    trigger => quote_sub(q{(shift)->wrapper->timeout(shift) if scalar @_ > 1}),
 );
 
 has '+wrapper' => (
-    isa => 'Net::Telnet',
+    isa => InstanceOf['Net::Telnet'],
 );
 
-override '_build_wrapper' => sub {
-    my $self = shift;
+around '_build_wrapper' => sub {
+    my ($orig, $self) = (shift, shift);
 
     $self->logger->log('transport', 'notice', 'creating Net::Telnet wrapper for', $self->app);
-    super();
+    $self->$orig(@_);
 
     $SIG{CHLD} = 'IGNORE'
         if not $self->connect_options->reap;
