@@ -1,13 +1,13 @@
 package Net::CLI::Interact::Transport::SSH;
 {
-  $Net::CLI::Interact::Transport::SSH::VERSION = '2.123370_002';
+  $Net::CLI::Interact::Transport::SSH::VERSION = '2.122630';
 }
 
 use Moo;
 use Sub::Quote;
 use MooX::Types::MooseLike::Base qw(InstanceOf);
 
-extends 'Net::CLI::Interact::Transport::Base';
+extends 'Net::CLI::Interact::Transport';
 
 {
     package # hide from pause
@@ -107,9 +107,9 @@ Net::CLI::Interact::Transport::SSH - SSH based CLI connection
 
 =head1 VERSION
 
-version 2.123370_002
+version 2.122630
 
-=head1 DESCRIPTION
+=head1 DECRIPTION
 
 This module provides a wrapped instance of an SSH client for use by
 L<Net::CLI::Interact>.
@@ -191,7 +191,7 @@ See the following for further interface details:
 
 =item *
 
-L<Net::CLI::Interact::Transport::Base>
+L<Net::CLI::Interact::Transport>
 
 =back
 
