@@ -1,13 +1,13 @@
 package Net::CLI::Interact::Transport::Serial;
 {
-  $Net::CLI::Interact::Transport::Serial::VERSION = '2.123370_002';
+  $Net::CLI::Interact::Transport::Serial::VERSION = '2.122630';
 }
 
 use Moo;
 use Sub::Quote;
 use MooX::Types::MooseLike::Base qw(InstanceOf);
 
-extends 'Net::CLI::Interact::Transport::Base';
+extends 'Net::CLI::Interact::Transport';
 
 {
     package # hide from pause
@@ -15,7 +15,7 @@ extends 'Net::CLI::Interact::Transport::Base';
 
     use Moo;
     use Sub::Quote;
-    use MooX::Types::MooseLike::Base qw(Str Bool Int ArrayRef Any);
+    use MooX::Types::MooseLike::Base qw(Str Bool Int);
 
     extends 'Net::CLI::Interact::Transport::Options';
 
@@ -43,12 +43,6 @@ extends 'Net::CLI::Interact::Transport::Base';
         isa => Int,
         default => quote_sub('9600'),
     );
-
-    has 'opts' => (
-        is => 'rw',
-        isa => ArrayRef[Any],
-        default => sub { [] },
-    );
 }
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -71,11 +65,7 @@ sub runtime_options {
     my $self = shift;
 
     if ($self->is_win32) {
-        return (
-            '-serial',
-            @{$self->connect_options->opts},
-            $self->connect_options->device,
-        );
+        return ('-serial',);
     }
     else {
         return (
@@ -83,7 +73,6 @@ sub runtime_options {
             ('-l ' . $self->connect_options->device),
             ('-s ' . $self->connect_options->speed),
             ($self->connect_options->nostop ? '--nostop' : ()),
-            @{$self->connect_options->opts},
         );
     }
 }
@@ -102,9 +91,9 @@ Net::CLI::Interact::Transport::Serial - Serial-line based CLI connection
 
 =head1 VERSION
 
-version 2.123370_002
+version 2.122630
 
-=head1 DESCRIPTION
+=head1 DECRIPTION
 
 This module provides a wrapped instance of a Serial-line client for use by
 L<Net::CLI::Interact>.
@@ -148,12 +137,6 @@ value.
 You can set the speed (or I<baud rate>) of the serial line by passing a value
 to this named parameter. The default is C<9600>.
 
-=item opts
-
-If you want to pass any other options to the application, then use
-this option, which should be an array reference. Each item in the list will be
-passed to the application, separated by a single space character.
-
 =item reap
 
 Only used on Unix platforms, this installs a signal handler which attempts to
@@ -170,7 +153,7 @@ See the following for further interface details:
 
 =item *
 
-L<Net::CLI::Interact::Transport::Base>
+L<Net::CLI::Interact::Transport>
 
 =back
 
